@@ -3,7 +3,8 @@
 ;; Copyright (C) 2025 Huang Feiyu
 
 ;; Author: Huang Feiyu <sibadake1@163.com>
-;; Version: 3.0.2
+;; Package-Version: 3.0.3
+;; Package-Revision: e66dba299ed3
 ;; Package-Requires: ((emacs "27.1") (posframe "1.4.0") (eglot "1.8"))
 ;; Keywords: tools, languages, convenience, mouse, hover
 ;; URL: https://github.com/huangfeiyu/eldoc-mouse
@@ -171,6 +172,10 @@ this list for specific mode.")
     (setq eldoc--last-request-state nil)
     (eldoc-print-current-symbol-info)))
 
+;; Don't restore the minor mode.
+(with-eval-after-load 'desktop
+  (add-to-list 'desktop-minor-mode-handlers '(eldoc-mouse-mode . ignore)))
+
 (defun eldoc-mouse-enable ()
   "Enable eldoc-mouse in buffers."
   ;; Enable mouse tracking.
